@@ -5,6 +5,19 @@ import cv2
 import random
 
 from calculation.pixel import Pixel
+from skimage.measure import find_contours, approximate_polygon
+
+
+class Config:
+    # Parameter of simplify_cords. İf increase this parameter function does more simplicate
+    simplify_parameter: int = 4
+
+    # Value of max line on segmentation
+    threshold_line: int = 24
+
+    # Model threshold value
+    thresh_test: int = 0.8
+
 
 class PostProcessor:
 
@@ -199,6 +212,70 @@ class PostProcessor:
         res = [x + 0.5 for x in res if len(x) >= 6]
         return res, has_holes
 
+    @staticmethod
+    def get_boundary_box_and_seg(bbox: list, mask: list) -> tuple:
+        """
+        :param seg: List of obtain polygon points
+        :param simplify_parameter: Parameter of simplify_coords. İf increase this parameter function does more simplicate
+         polygon points.
+        :return: Simplicated list of points, corner points, center points
+        """
+
+        contours = find_contours(mask)
+        polygon_boundry = [approximate_polygon(p, tolerance=2) for p in contours]
+
+        for polygon_points in polygon_boundry[0]:
+            polygon_points[0], polygon_points[1] = polygon_points[1], polygon_points[0]
+
+        polygon_points = list(polygon_boundry[0])
+        polygon_points = [list(elem) for elem in polygon_points]
+
+        # Bbox output
+
+        # Bbox corners
+        corner_1 = [bbox[0], bbox[1]]
+        corner_2 = [bbox[2], bbox[3]]
+        corner_3 = [bbox[2], bbox[1]]
+        corner_4 = [bbox[0], bbox[3]]
+
+        # Bbox list
+        bbox_corners = [corner_1, corner_3, corner_2, corner_4]
+
+        # Center
+        center_1 = Pixel.middle_points_pixels(corner_1, corner_2)
+        center_2 = Pixel.middle_points_pixels(corner_3, corner_4)
+
+        center = Pixel.middle_points_pixels(center_1, center_2)
+
+        # Limiting points based on threshold_line value
+        if len(polygon_points) > Config.threshold_line:
+            distance_list: list = []
+            for i in range(0, len(polygon_points) - 1, 1):
+                distance_list.append(
+                    (Pixel.distance_pixels(polygon_points[i], polygon_points[i + 1]), polygon_points[i], polygon_points[i + 1]))
+            while len(polygon_points) != Config.threshold_line:
+                distance_list.sort()
+                polygon_points.remove(distance_list[0][1])
+                distance_list.remove(distance_list[0])
+
+        # Specify segmentation corners
+        result = []
+        list_corner = []
+        for sira, x in enumerate(bbox_corners):
+            for elem in polygon_points:
+                result.append((Pixel.distance_pixels(x, elem), elem))
+            result.sort()
+            if result[0][1] not in list_corner:
+                list_corner.append(result[0][1])
+            else:
+                list_corner.append(result[1][1])
+            result.clear()
+
+        list_corner.insert(0, center)
+        center_and_corners = list_corner
+
+        return polygon_points, center_and_corners
+
 
 def calc_rgb_histogram(img: np.ndarray, isNormalized: bool = True) -> Tuple:
     h_b = cv2.calcHist([img], [0], None, [256], [0, 255])
